Computes similarities for nodes of interest on the fly to avoid having to deal with very large similarity matrices when number of features is large.
build_kgraph_from_fit(selected_concepts, m_embeds, fit_kg, ...)Knowledge graph, list of slots df_nodes and df_links
Concepts of interest
Embeddings matrix
Fit object
Passed to build_kgraph