Learn R Programming

kgraph (version 1.2.0)

gen_df_notpairs: Generate null pairs

Description

Generate null pairs

Usage

gen_df_notpairs(
  ids,
  df_pairs = NULL,
  n_notpairs = if (is.null(df_pairs)) 1000 else nrow(df_pairs)
)

Value

Data frame with columns concept1, concept2, weight

Arguments

ids

Identifiers to sample from

df_pairs

Known pairs data frame, to make sure no null pairs are in

n_notpairs

Direct parameter to set number of null pairs returned, bypasses parameter type.